==> task-serdes-kryo-22.2.1-sources.jar: io/altoo/akka/serialization/kryo/KryoAkkaSerializer.scala <==
package io.altoo.akka.serialization.kryo

import ai.digital.deploy.task.serdes.TaskAkkaSerializer
import ai.digital.deploy.task.serdes.kryo.{KryoSerializer, WorkDirSerializer}
import akka.actor.ExtendedActorSystem
import akka.event.LoggingAdapter
import com.esotericsoftware.kryo.Kryo
import com.xebialabs.deployit.repository.WorkDir

class KryoAkkaSerializer(system: ExtendedActorSystem) extends KryoSerializer(system) with TaskAkkaSerializer {
  private val serializerPoolOnSuper = this.getClass.getSuperclass.getDeclaredField("serializerPool")
  serializerPoolOnSuper.setAccessible(true)

  private val queueBuilderClassOnSuper = this.getClass.getSuperclass.getDeclaredField("queueBuilderClass")
  queueBuilderClassOnSuper.setAccessible(true)
  private val queueBuilderClass = queueBuilderClassOnSuper.get(this).asInstanceOf[Class[_]]

  private val settingsOnSuper = this.getClass.getSuperclass.getDeclaredField("settings")
  settingsOnSuper.setAccessible(true)
  private val settings = settingsOnSuper.get(this).asInstanceOf[KryoSerializationSettings]

  private val logOnSuper = this.getClass.getSuperclass.getDeclaredField("log")
  logOnSuper.setAccessible(true)
  private val log = logOnSuper.get(this).asInstanceOf[LoggingAdapter]

  private val pool = new SerializerPool(
    queueBuilderClass.getDeclaredConstructor().newInstance().asInstanceOf[DefaultQueueBuilder],
    () => new KryoSerializerBackend(
      getCustomKryo,
      settings.bufferSize,
      settings.maxBufferSize,
      settings.useManifests,
      settings.useUnsafe
    )(log)
  )

  serializerPoolOnSuper.set(this, pool)

  var kryoCustomizers: Seq[KryoCustomizer] = Seq()

  def setKryoCustomizers(kryoCustomizer: KryoCustomizer*): Unit = {
    kryoCustomizers = kryoCustomizer
  }

  private def getCustomKryo: Kryo = {
    val kryo = KryoSerializer.getMagicCombination(system)
    kryoCustomizers.foreach(_.customize(kryo))
    kryo
  }

  override def initExternalWorker(conf: TaskAkkaSerializer.Conf): Unit = {
    setKryoCustomizers(
      (kryo: Kryo) => kryo.addDefaultSerializer(classOf[WorkDir], new WorkDirSerializer(kryo, conf.baseWorkDir, true))
    )
  }
}

trait KryoCustomizer {
  def customize(kryo: Kryo): Unit
}

==> task-serdes-kryo-23.1.0-rc.1-sources.jar: io/altoo/akka/serialization/kryo/KryoAkkaSerializer.scala <==
package io.altoo.akka.serialization.kryo

import ai.digital.deploy.task.serdes.TaskAkkaSerializer
import ai.digital.deploy.task.serdes.kryo.{KryoSerializer, WorkDirSerializer}
import akka.actor.ExtendedActorSystem
import akka.event.LoggingAdapter
import com.esotericsoftware.kryo.Kryo
import com.xebialabs.deployit.repository.WorkDir

class KryoAkkaSerializer(system: ExtendedActorSystem) extends KryoSerializer(system) with TaskAkkaSerializer {
  private val serializerPoolOnSuper = this.getClass.getSuperclass.getDeclaredField("serializerPool")
  serializerPoolOnSuper.setAccessible(true)

  private val queueBuilderClassOnSuper = this.getClass.getSuperclass.getDeclaredField("queueBuilderClass")
  queueBuilderClassOnSuper.setAccessible(true)
  private val queueBuilderClass = queueBuilderClassOnSuper.get(this).asInstanceOf[Class[_]]

  private val settingsOnSuper = this.getClass.getSuperclass.getDeclaredField("settings")
  settingsOnSuper.setAccessible(true)
  private val settings = settingsOnSuper.get(this).asInstanceOf[KryoSerializationSettings]

  private val logOnSuper = this.getClass.getSuperclass.getDeclaredField("log")
  logOnSuper.setAccessible(true)
  private val log = logOnSuper.get(this).asInstanceOf[LoggingAdapter]

  private val pool = new SerializerPool(
    queueBuilderClass.getDeclaredConstructor().newInstance().asInstanceOf[DefaultQueueBuilder],
    () => new KryoSerializerBackend(
      getCustomKryo,
      settings.bufferSize,
      settings.maxBufferSize,
      settings.useManifests,
      settings.useUnsafe
    )(log)
  )

  serializerPoolOnSuper.set(this, pool)

  var kryoCustomizers: Seq[KryoCustomizer] = Seq()

  def setKryoCustomizers(kryoCustomizer: KryoCustomizer*): Unit = {
    kryoCustomizers = kryoCustomizer
  }

  private def getCustomKryo: Kryo = {
    val kryo = KryoSerializer.getMagicCombination(system)
    kryoCustomizers.foreach(_.customize(kryo))
    kryo
  }

  override def initExternalWorker(conf: TaskAkkaSerializer.Conf, createWorkDir: Boolean = true): Unit = {
    setKryoCustomizers(
      (kryo: Kryo) => kryo.addDefaultSerializer(classOf[WorkDir], new WorkDirSerializer(kryo, conf.baseWorkDir, createWorkDir))
    )
  }
}

trait KryoCustomizer {
  def customize(kryo: Kryo): Unit
}
